""" Addon Information """
# ------------
# EventScripts Script-Addon:    KnifeSyphon ESP (syphon.py, 6.7kb)
# Author:                       BackRaw - http://forums.eventscripts.com/profile.php?mode=viewprofile&u=13683
#                                         http://addons.eventscripts.com/addons/user/13683
# Version:                      1.0
# ------------

""" Imports """
# ------------
# EventScripts Core-Module            - ES-functionality
import es
# Gamethread                          - Delayed functions
from gamethread import delayed
# Random                              - Randomized choices
from random import choice
# Config Object                       - Configuration-File: ./addons/eventscripts/bdm/bdm_config.ini
from configobj import ConfigObj
# ------------

""" Global Variables """
# ------------
# This player-dictionary will hold every player in the class "Syphon".
# It will set the player's health if a knife-kill was done, or, if more were done, it will give a free gift (randomized).
# ------------
player = {}

""" Classes - Configuration """
# ------------
# This will get the config values of types str, and int for easier handling.
# ------------
class Configuration(object):
    def __init__(self, name, _section=False):
        self.file = ConfigObj(es.getAddonPath('syphon') + '/syphon_config.ini')
        self.name = name
        self.section = _section
    def getString(self):
        try:
            if self.section:
                return self.file[self.section][self.name]
            return self.file[self.name]
        except ValueError, e:
            raise e
    def getInt(self):
        try:
            if self.section:
                return int(self.file[self.section][self.name])
            return int(self.file[self.name])
        except ValueError:
            raise TypeError, 'Type of "int" is not readable (is it a string?)'

""" Instances - config (Configuration)"""
# ------------
# Call this instance instead of calling the Configuration class itself.
# ------------
def config(name, _section=False):
    return Configuration(name, _section)

""" Classes - Syphon """
# ------------
# This will handle all the knife-kill stuff.
# ------------
class Syphon(object):
    def __init__(self, userid):
        self.userid = userid
        self.kills = 0
        self.choices = 0
    """ Wrapper for es_give command for easier handling """
    def give(self, cmd):
        es.server.queuecmd('es_xgive %s %s' % (self.userid, cmd))
    """ player_spawn """
    def spawn(self):
        if self.kills:
            health = es.getplayerprop(self.userid, 'CBasePlayer.m_iHealth') + (40 * self.kills)
            es.setplayerprop(self.userid, 'CBasePlayer.m_iHealth', health)
            es.tell(self.userid, '#multi', '#green[#lightgreenKnifeSyphon ESP#green] #defaultGained #lightgreen%s #defaultHealth for killing #lightgreen%s #defaultplayers with a #lightgreenKnife' % (health, self.kills))
            if self.kills > 1:
                option = choice(['nade', 'armor', 'weapon'])
                text = 'a free #lightgreen'
                if option == 'nade':
                    nade = config('nade', 'more kills').getString()
                    self.give('weapon_%s' % nade)
                    text += nade.replace('hegrenade', 'HE-Grenade').replace('flashbang', 'Flashbang')
                    if config('doubleflash', 'more kills').getInt() and nade == 'flashbang':
                        self.give('weapon_hegrenade')
                        text = text.replace('a', '2')
                        text += 's'
                elif option == 'armor':
                    armor = config('armor', 'more kills').getInt()
                    self.give('item_assaultsuit')
                    delayed(0, es.setplayerprop, (self.userid, 'CCSPlayer.m_ArmorValue', es.getplayerprop(self.userid, 'CCSPlayer.m_ArmorValue') + armor))
                    text = '#lightgreen%s #defaultmore #lightgreenArmor' % armor
                elif option == 'weapon':
                    wep = config('weapon', 'more kills').getString()
                    self.give('weapon_%s' % wep)
                    text += wep
                es.tell(self.userid, '#multi', '#green[#lightgreenKnifeSyphon ESP#green] #defaultGot %s' % text)
            self.kills = 0
    """ player_death """
    def death(self, weapon, userteam, hp):
        if weapon == 'knife' and es.getplayerteam(self.userid) != userteam:
            health = config('health', 'one kill').getInt()
            es.setplayerprop(self.userid, 'CBasePlayer.m_iHealth', hp + health)
            es.tell(self.userid, '#multi', '#green[#lightgreenKnifeSyphon ESP#green] #defaultGot #lightgreen%s #defaultHealth for killing with a #lightgreenKnife' % health)
            self.kills += 1

""" Instances - syphonPlayer (Syphon) """
# ------------
# We want to call this instead of calling the Syphon class itself.
# ------------
def syphonPlayer(userid):
    if es.exists('userid', userid):
        return Syphon(userid)
    raise TypeError, 'UserID %s does not exist!' % userid

""" End of Classes - Start Events """
# ------------
# This will add the connected player to our player-dictionary.
# ------------
def player_activate(ev):
    userid = ev['userid']
    player[userid] = syphonPlayer(userid)

# ------------
# On spawn, fire "spawn" in the Syphon-Class.
# ------------
def player_spawn(ev):
    userid = ev['userid']
    if int(ev['es_userteam']) > 1 and player.has_key(userid):
        player[userid].spawn()

# ------------
# On death, fire "death" in the Syphon-Class.
# ------------
def player_death(ev):
    player[ev['attacker']].death(ev['weapon'], int(ev['es_userteam']), int(ev['es_attackerhealth']))

# ------------
# Remove the disconnecting player from our player-dictionary.
# ------------
def player_disconnect(ev):
    del player[ev['userid']]

# ------------
# If set to 1 in the configuration file, announce that KnifeSyphon ESP is loaded and ready to rock and roll.
# ------------
def round_start(ev):
    if config('announce').getInt():
        es.msg('#multi', '#green[#lightgreenKnifeSyphon ESP#green] #defaultAny player can get a health boost by killing with a #lightgreenKnife')

""" End of Events - Start EvetScripts Main-Control Functions """
# ------------
# On load, add every existing player to our player-dictionary, so they can get knife-rewards on-the-fly, and set the public variable.
# ------------
def load():
    es.ServerVar('knife_syphon_esp', '1.0').makepublic()
    for userid in es.getUseridList():
        userid = str(userid)
        player[userid] = syphonPlayer(userid)

# ------------
# On unload, remove players from our player-dictionary.
# ------------
def unload():
    player.clear()

""" End Code """
